# YT_AudioStream
```diff
+ This is a simple script that can stream audio from youtube based on search results you give.
! You should have VLC media player installed on your system to use this.
@@ EDIT: You can now install this via pip @@
```
Works on linux.
Not tested on Windows and Mac.


```pip install ytstreamer```
